#
# spec file for package gjs
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gjs
Version:        1.50.4
Release:        lp150.2.1
# FIXME: find out if tapsets should really be in devel package or in main package
Summary:        JavaScript bindings based on gobject-introspection and Mozilla
License:        MIT
Group:          Development/Libraries/GNOME
Url:            https://wiki.gnome.org/Projects/Gjs
Source:         https://download.gnome.org/sources/gjs/1.50/%{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  mozjs52-devel
BuildRequires:  pkgconfig
BuildRequires:  python
BuildRequires:  readline-devel
BuildRequires:  systemtap-sdt-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(cairo-gobject)
BuildRequires:  pkgconfig(cairo-xlib)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0) >= 2.50.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.53.4
BuildRequires:  pkgconfig(gthread-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(libffi)
#BuildRequires:  pkgconfig(mozjs-52)
Requires:       libgjs0 = %{version}
ExcludeArch:    s390

%description
This module contains JavaScript bindings based on gobject-introspection and the
Mozilla SpiderMonkey JavaScript engine.

%package -n libgjs0
Summary:        JavaScript bindings based on gobject-introspection and Mozilla
Group:          System/Libraries
Provides:       libgjs-0 = %{version}
Obsoletes:      libgjs-0 < %{version}

%description -n libgjs0
This module contains JavaScript bindings based on gobject-introspection and the
Mozilla SpiderMonkey JavaScript engine.

%package -n typelib-1_0-GjsPrivate-1_0
Summary:        Introspection bindings for the GJS library
# The tyeplib was renamed in gnome 3.6, to reflect it is a private lib.
Group:          System/Libraries
Obsoletes:      typelib-1_0-GjsDBus-1_0 < %{version}

%description -n typelib-1_0-GjsPrivate-1_0
This module contains JavaScript bindings based on gobject-introspection and the
Mozilla SpiderMonkey JavaScript engine.

%package -n libgjs-devel
Summary:        Development files for the GJS library
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}
Requires:       libgjs0 = %{version}
Requires:       typelib-1_0-GjsPrivate-1_0 = %{version}
# Just a helper provides
Provides:       gjs-devel = %{version}

%description -n libgjs-devel
This module contains JavaScript bindings based on gobject-introspection and the
Mozilla SpiderMonkey JavaScript engine.

%prep
%setup -q

%build
%configure \
    --disable-static \
    --enable-systemtap
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libgjs0 -p /sbin/ldconfig

%postun -n libgjs0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/gjs
%{_bindir}/gjs-console

%files -n libgjs0
%defattr(-,root,root)
%doc COPYING NEWS README
%{_libdir}/*.so.*

%files -n typelib-1_0-GjsPrivate-1_0
%defattr(-,root,root)
%dir %{_libdir}/gjs
%dir %{_libdir}/gjs/girepository-1.0/
%{_libdir}/gjs/girepository-1.0/GjsPrivate-1.0.typelib

%files -n libgjs-devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/systemtap/tapset/*.stp

%changelog
* Mon Feb 19 2018 fcrozat@suse.com
- Do not try to build against s390 anymore, since it doesn't build
  with mozjs54 and s390 is only for compability with old
  applications (gjs doesn't qualifies).
* Tue Jan 30 2018 bjorn.lie@gmail.com
- Update to version 1.50.4:
  + Gnome Shell crash with places-status extension when you plug an
    USB device (glgo#gjs#33 and glgo#gjs#38).
- Changes from version 1.50.3:
  + GJS will now log a warning when a GObject is accessed in
    Javascript code after the underlying object has been freed in
    C. (This used to work most of the time, but crash
    unpredictably.) We now prevent this situation which, is usually
    by caused a memory management bug in the underlying C library.
  + Closed bugs and merge requests:
  - Add checks for GObjects that have been finalized
    (glgo#gjs#21, glgo#gjs#23, glgo#gjs#25, glgo#gjs#28,
    glgo#gjs#33).
  - Test "Cairo context has methods when created from a C
    function" fails (glgo#gjs#27, glgo#gjs#35).
  - Various fixes from the master branch for rare crashes.
* Tue Oct 31 2017 luc14n0@linuxmail.org
- Update to version 1.50.2:
  + Closed bugs and merge requests:
  - tweener: Fix a couple of warnings.
  - legacy: Allow ES6 classes to inherit from abstract Lang.Class
    class.
  + Minor bugfixes.
- Update Url to https://wiki.gnome.org/Projects/Gjs: current Gjs'
  project web page.
- Alignment BuildRequires with configure:
  + Add pkgconfig(*): cairo-gobject, gio-2.0, gobject-2.0 and
    gthread-2.0.
  + Drop pkgconfig(libmozjs-52) and libxml2-tools.
* Tue Oct  3 2017 zaitor@opensuse.org
- Update to version 1.50.1:
  + As a debugging aid, gjs_dumpstack() now works even during
    garbage collection.
  + Code coverage tools did not work so well in the last few 1.49
    releases. The worst problems are now fixed, although even more
    improvements will be released in the next unstable version.
    Fixes include:
  - Specifing prefixes for code coverage files now works again.
  - Code coverage now works on lines inside ES6 class
    definitions.
  - The detection of which lines are executable has been improved
    a bit.
* Mon Sep 11 2017 jengelh@inai.de
- Rectify summaries.
* Mon Sep 11 2017 dimstar@opensuse.org
- Update to version 1.50.0:
  + Relicense coverage.cpp and coverage.h to the same license as
    the rest of GJS (bgo#787263).
- Change license back to MIT.
* Tue Sep  5 2017 dimstar@opensuse.org
- Update to version 1.49.92:
  + It's now possible to build GJS with sanitizers (ASan and
    UBSan) enabled; add "--enable-asan" and "--enable-ubsan" to
    your configure flags.
  + There's also a "make check-valgrind" target which will run
    GJS's test suite under Valgrind to catch memory leaks and
    threading races.
  + Many of the crashes in GNOME 3.24 were caused by GJS's closure
    invalidation code which had to change from the known-working
    state in 1.46 because of changes to SpiderMonkey's garbage
    collector. This code has been refactored to be less
    complicated, which will hopefully improve stability and
    debuggability.
  + Docs tweaks.
  + Bugs fixed: bgo#783220, bgo#786668, bgo#786995, bgo#787113.
* Mon Sep  4 2017 dimstar@opensuse.org
- Temporariliy change license to GPL-2.0+: there are a couple files
  in the source tree, that link into libgjs and bring the code to
  GPL-2.0+ level; upstream is working on relicensing them
  (bgo#787263).
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 1.49.91:
  + Deprecation: The private "__name__" property on Lang.Class
    instances is now discouraged. Code should not have been using
    this anyway, but if it did then it should use the "name"
    property on the class (this.__name__ should become
    this.constructor.name), which is compatible with ES6 classes.
  + Closed bugs:
  - Use ES6 classes (bgo#785652).
  - A few fixes for stack traces and error reporting
    (bgo#786183).
  - /proc/self/stat is read for every frame if GC was not needed
    (bgo#786017).
  + Build fix.
* Mon Aug 21 2017 dimstar@opensuse.org
- Update to version 1.49.90:
  + New API: GObject.registerClass(), intended for use with ES6
    classes.
  + Misc 1.49 and mozjs52 enhancements (bgo#785040).
  + Switch to native promises (bgo#784713).
  + Can't call exports using top-level variable toString
    (bgo#781623).
  + Properties no longer recognized when shadowed by a method
    (bgo#785091).
  + Backport of changes required for use with mozjs-55.
- Changes from version 1.49.6:
  + GJS crash in needsPostBarrier, possible access from wrong
    thread (bgo#783935).
- Changes from version 1.49.4:
  + This version of GJS is based on SpiderMonkey 52.
  + New language features
  - ES6 classes.
  - Async functions and await operator.
  - Reflect - built-in object with methods for interceptable
    operations.
  + Backwards-incompatible changes
  - Non-standard "let expressions" and "let blocks" (e.g.,
    `let (x = 5) { use(x) }`) are not supported any longer
  - Non-standard flags argument to String.match(),
    String.replace(), and String.search() (e.g.
    `str.replace('foo', 'bar', 'g')`) is now ignored.
  - Non-standard WeakSet.clear() method has been removed.
  - Variables declared with let and const are now 'global lexical
    bindings', as per the ES6 standard, meaning that they will
    not be exported in modules.
  + Closed bugs:
  - Prepare for SpiderMonkey 45 and 52 (bgo#781429).
  - Add a static analysis tool as a make target (bgo#783214).
  - Fix the build with debug logs enabled (bgo#784469).
  - Switch to SpiderMonkey 52 (bgo#784196).
  - Test suite fails when run with JIT enabled (bgo#616193).
- Replace pkgconfig(mozjs-38) BuildRequires for
  pkgconfig(mozjs-52), following upstreams port.
- Add libxml2-tools BuildRequires: new dependency.
* Wed Aug 16 2017 dimstar@opensuse.org
- Update to version 1.49.3:
  + Fixes in preparation for SpiderMonkey 52.
  + Use the Centricular fork of libffi to build on Windows.
  + Use a C++ auto pointer instead of g_autofree (bgo#777597).
  + Build failure in GNOME Continuous (bgo#783031).
* Wed Aug 16 2017 zaitor@opensuse.org
- Update to version 1.49.2:
  + New feature: When building an app with the Package module,
    using the Meson build system, you can now run the app with
    "ninja run" and all the paths will be set up correctly.
  + New feature: Gio.ListStore is now iterable.
  + New API: Package.requireSymbol(), a companion for the already
    existing Package.require(), that not only checks for a GIR
    library but also for a symbol defined in that library.
  + New API: Package.checkSymbol(), similar to
    Package.requireSymbol() but does not exit if the symbol was not
    found. Use this to support older versions of a GIR library with
    fallback functionality.
  + New API: System.dumpHeap(), for debugging only. Prints the
    state of the JS engine's heap to standard output. Takes an
    optional filename parameter which will dump to a file instead
    if given.
  + Fixes in preparation for SpiderMonkey 52.
  + Misc fixes.
  + Bugs fixed: bgo#775868, bgo#781882, bgo#781882, bgo#782065,
    bgo#782069, bgo#779593, bgo#782310, bgo#781219, bgo#780106.
* Wed Aug 16 2017 zaitor@opensuse.org
- Update to version 1.49.1:
  + test GObject Class failure (bgo#693676).
  + Enable incremental GCs (bgo#724797).
  + Don't silently accept extra arguments to C functions
    (bgo#680215).
  + Special case GValues in signals and properties (bgo#688128).
  + [cairo]: Instantiate wrappers properly (bgo#614413).
  + Warn if we're importing an unversioned namespace (bgo#689654).
  + Fixes in preparation for SpiderMonkey 45.
* Wed Aug 16 2017 zaitor@opensuse.org
- Update to version 1.48.6:
  + GJS crash in needsPostBarrier, possible access from wrong
    thread - more fixes for bgo#783935.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 1.48.5:
  + GJS crash in needsPostBarrier, possible access from wrong
    thread (bgo#783935).
  + Fix format string, caught by static analysis.
  + Fixes for regression in 1.48.4.
* Fri Jun 16 2017 zaitor@opensuse.org
- Update to version 1.48.4:
  + gnome-shell 3.24.1 crash on wayland (bgo#781799).
* Sun May  7 2017 zaitor@opensuse.org
- Update to version 1.48.3:
  + arg: don't crash when asked to convert a null strv to an array
    (bgo#775679).
  + gjs 1.48.0: does not compile on macOS with clang (bgo#780350).
  + Modernize shell scripts (bgo#781806).
- Changes from version 1.48.2:
  + Intermittent crash in gnome-shell, probably in weak pointer
    updating code (bgo#781194).
  + Add contributor's guide (bgo#781297).
  + Misc fixes.
* Mon Apr 10 2017 zaitor@opensuse.org
- Update to version 1.48.1:
  + gjs crashed with SIGSEGV in gjs_object_from_g_object
    (bgo#779918).
  + Misc bug fixes.
* Thu Mar 23 2017 jengelh@inai.de
- Drop redundant %%clean section.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 1.48.0:
  + Memory leak in object_instance_resolve() (bgo#780171).
- Drop gjs-object-Fix-memory-leak-in-resolve.patch: fixed upstream.
* Thu Mar 16 2017 luke.nukem.jones@gmail.com
- Add patch gjs-object-Fix-memory-leak-in-resolve.patch: The "name"
  string, allocated in gjs_get_string_id(), wasn't getting freed at
  every exit point of the function (bgo#780171).
* Tue Mar 14 2017 zaitor@opensuse.org
- Update to version 1.47.92:
  + gjs 1.47.91 configure fails with Fedora's mozjs38 (bgo#779412).
  + tests: Don't fail when Gtk+-4.0 is available (bgo#779594).
  + gjs 1.47.91 test failures on non-amd64 (bgo#779399).
  + gjs_eval_thread should always be set (bgo#779693).
  + System.exit() should exit even across main loop iterations
    (bgo#779692).
  + Fix a typo in testCommandLine.sh (bgo#779772).
  + arg: Fix accidental fallthrough (bgo#779838).
  + jsUnit: Explicitly check if tempTop.parent is defined
    (bgo#779871).
  + Misc bug fixes.
- Drop mozjs38 BuildRequires and stop passing JS_INTERP=/usr/bin/js
  to configure: No longer needed after upstream fixes.
* Tue Feb 28 2017 zaitor@opensuse.org
- Update to version 1.47.91:
  + overrides/Gio: Provide an empty array on error, rather than
    null (bgo#677513).
  + WithSignals parameter for Lang.Class (bgo#664897).
  + Add API to better support asynchronous code (bgo#608450).
  + Fix 1.47.90 tests are failing (bgo#778780).
  + boxed: Plug a memory leak (bgo#779036).
  + Don't crash when marshalling an unsafe integer from
    introspection (bgo#778705).
  + Lang.Class should include symbol properties (bgo#778718).
  + Console output of arrays should be UTF-8 aware (bgo#778729).
  + Various fixes for 1.47.91 (bgo#779293).
  + Progress towards a Visual Studio build of GJS on Windows.
  + Misc bug fixes.
- Pass JS_INTERP=/usr/bin/js to configure in order to help it find
  the default, unversioned js binary.
- Add moyjs38 BuildRequires: the mozjs interpreter is not installed
  per default together with mozjs-devel.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 1.47.90:
  + This version of GJS is based on SpiderMonkey 38.
  + Syntax enhancements.
  + Various API additions.
  + Backwards-incompatible changes:
  - It is now a syntax error to declare the same variable twice
    with "let" or "const" in the same scope. Existing code may
    need to be fixed, but the fix is trivial.
    + SpiderMonkey is now extra vocal about warning when you access
    an undefined property, and this causes some false positives.
    You can turn this warning off by setting
    GJS_DISABLE_EXTRA_WARNINGS=1.
    + When enumerating the importer object (i.e.,
    "for (let i in imports) {...}") you will now get the names of
    any built-in modules that have previously been imported.
  + Bugs fixed: bgo#776966, bgo#777205, bgo#642506, bgo#776549,
    bgo#777962.
- Replace pkgconfig(mozjs-31) BuildRequires with
  pkgconfig(mozjs-38), following upstreams port.
* Fri Jan 20 2017 dimstar@opensuse.org
- Update to version 1.47.4:
  + News for GJS embedders such as gnome-shell:
  - New API: The GjsCoverage type and its methods are now
    exposed. Use this if you are embedding GJS and need to output
    code coverage statistics.
  + Bugs fixed: bgo#563391, bgo#619710, bgo#636283, bgo#697020,
    bgo#730101, bgo#737607, bgo#742852, bgo#751146, bgo#760057,
    bgo#775444, bgo#775776, bgo#776193, bgo#776938.
* Tue Dec 13 2016 dimstar@opensuse.org
- Update to version 1.47.3:
  + New JavaScript features! This version of GJS is based on
    SpiderMonkey 31, an upgrade from the previous ESR (Extended
    Support Release) of SpiderMonkey 24.
  + New syntax:
  - Spread operator in function calls: someFunction(arg1, arg2,
    ...iterableObj).
  - Generator functions: yield, function*, yield*.
  - Binary and octal numeric literals: 0b10011100, 0o377.
  - Function arguments without defaults can now come after those
    with defaults: function f(x=1, y) {}.
  + New standard library module: Intl - Locale-sensitive formatting
    and string comparison.
  + New behaviour:
  - -0 and +0 are now considered equal as Map keys and Set
    values.
  - On typed arrays, numerical indexed properties ignore the
    prototype object:
    Int8Array.prototype[20] = 'foo';(new Int8Array(32))[20] == 0.
  + New non-standard Mozilla extensions:
  - Array comprehensions.
  - Generator comprehensions; both were originally proposed for
    ES6 but removed.
  + Bugs fixed: bgo#573335, bgo#595439, bgo#605972, bgo#742249,
    bgo#751252, bgo#770244, bgo#771598, bgo#771745, bgo#772027,
    bgo#772033, bgo#772386, bgo#772790, bgo#773297, bgo#773335,
    bgo#775205.
- Replace pkgconfig(mozjs-24) BuildRequires with
  pkgconfig(mozjs-31), following upstreams port.
* Thu Nov 10 2016 dimstar@opensuse.org
- Update to version 1.47.0:
  + Backwards-incompatible change: we have changed the way certain
    JavaScript values are marshalled into GObject introspection 32
    or 64-bit signed integer values, to match the ECMA standard.
  + Backwards-incompatible change: we have changed the way
    gjs-console interprets command-line arguments.
- Add pkgconfig(gtk+-3.0) BuildRequires: enable GTK+ support.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 1.46.0:
  + Be future proof against Format fixes in SpiderMonkey
    (bgo#770111).
* Tue Jul 19 2016 zaitor@opensuse.org
- Update to version 1.45.4:
  + Release out args before freeing caller-allocated structs
    (bgo#768413).
  + Marshal variable array-typed signal arguments (bgo#761659).
  + Marshal all structs in out arrays correctly (bgo#761658).
  + Call setlocale() before processing arguments (bgo#760424).
  + Build fixes and improvements: bgo#737702, bgo#761072,
    bgo#761366, bgo#765905, bgo#767368.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Fri Dec 18 2015 damjanovic.ivo@gmail.com
- Update to version 1.45.3:
  + Support external construction of gjs-defined GObjects
    (bgo#681254).
  + Add new format.printf() API (bgo#689664).
  + Add new API to get the name of a repository (bgo#685413).
  + Add C to JS support for arrays of flat structures (bgo#704842).
  + Add API to specify CSS node name (bgo#758349).
  + Return value of default signal handler for "on_signal_name"
    (bgo#729288).
  + Fix multiple emissions of onOverwrite in Tweener (bgo#597927).
  + Misc bug fixes: bgo#727370, bgo#623330, bgo#667908,
    bgo#757763.
* Mon Nov  2 2015 zaitor@opensuse.org
- Update to version 1.44.0:
  + Add Lang.Interface and GObject.Interface (bgo#751343,
    bgo#752984).
  + Support callbacks with (transfer full) return types
    (bgo#750286).
  + Add binding for setlocale() (bgo#753072).
  + Improve support to generate code coverage reports (bgo#743009,
    bgo#743007, bgo#742362, bgo#742535, bgo#742797, bgo#742466,
    bgo#751732).
  + Report errors from JS property getters/setters (bgo#730101).
  + Fix crash when garbage collection triggers while inside an init
    function (bgo#742517).
  + Port to CallReceiver/CallArgs (bgo#742249).
  + Misc bug fixes (bgo#736979, bgo#753072, bgo#750688).
* Wed Feb  4 2015 dimstar@opensuse.org
- Require gjs by the devel package: a user installing the -devel
  package expects the interpreter to also be present.
* Sun Dec 21 2014 zaitor@opensuse.org
- Update to version 1.43.3:
  + GTypeClass and GTypeInterface methods, such as
    g_object_class_list_properties(), are now available
    (bgo#700347).
  + Added full automatic support for GTK widget templates
    (bgo#700347, bgo#737661, bgo##739739).
  + Added control of JS Date caches to system module (bgo#739790).
  + Misc bug fixes and memory leak fixes (bgo#738122, bgo#740696,
    bgo#737701).
* Mon Sep 29 2014 zaitor@opensuse.org
- Update to version 1.42.0:
  + Fix a regression caused by PPC fixes in 1.41.91.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 1.41.91:
  + Added the ability to disable JS language warnings (bgo#734569).
  + Fixed crashes in PPC (and probably other arches) due to invalid
    callback signatures (bgo#729554).
  + Fixed regressions with dbus 1.8.6 (bgo#735358).
  + Readded file system paths to the default module search, to
    allow custom GI overrides for third party libraries.
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 1.41.4:
  + Fixed memory management of GObject methods that unref their
    instance (bgo#729545).
  + Added a package module implementing the
    https://wiki.gnome.org/Projects/Gjs/Package application
    conventions (bgo#690136).
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 1.41.3:
  + Fixed GObject and Gtk overrides (bgo#727781, bgo#727394).
  + Fixed crashes caused by reentrancy during finalization
    (bgo#725024).
  + Added a wrapper type for cairo regions (bgo#682303).
  + Several cleanups to GC (bgo#725024).
  + Thread-safe structures are now finalized in the background, for
    greater responsiveness (bgo#725024, bgo#730030).
  + A full GC is now scheduled if after executing a piece of JS we
    see that the RSS has grown by over 150%% (bgo#725099,
    bgo#728048).
  + ParamSpecs now support methods and static methods implemented
    by glib and exposed by gobject-introspection, in addition to
    the manually bound fields (bgo#725282).
  + Protototypes no longer include static properties or
    constructors (bgo#725282).
  + Misc cleanups and bugfixes: bgo#727786, bgo#725282, bgo#728004,
    bgo#727824.
- Add pkgconfig(cairo-xlib) BuildRequires: new dependency.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 1.40.1:
  + Fixed build-time detection of GTK enablement (bgo#727394).
  + Fixed a crash caused by reentrancy in GObject finalizers
    (bgo#725024).
  + Fixed the GIMarshallingTests suite (bgo#728004).
  + Fixed marshalling of GObjects when known by an interface type
    from C to JS (bgo#727824).
  + Some typos and JS style cleanups (bgo#727781, bgo#727786).
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 1.40.0:
  + No changes from version 1.39.91.
* Tue Mar  4 2014 dimstar@opensuse.org
- Update to version 1.39.91:
  + Implemented fundamental object support (bgo#621716,
    bgo#725061).
  + Fixed GIRepositoryGType prototype (bgo#724925).
  + Moved GObject.prototype.disconnect() to a JS implementation
    (bgo#698283).
  + Added support for enumeration methods (bgo#725143).
  + Added pseudo-classes for fundamental types (bgo#722554).
  + Build fixes (bgo#724853).
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 1.39.90:
  + Enable coverage reports.
  + Minor bug fixes.
* Mon Jan 27 2014 dimstar@opensuse.org
- Update to version 1.39.3:
  + Bugs fixed: bgo#722286, bgo#722285, bgo#705465, bgo#705465,
    bgo#721246, bgo#721246, bgo#721246, bgo#721246, bgo#721246,
    bgo#721246, bgo#721246, bgo#721838, bgo#721355, bgo#721352,
    bgo#720157, bgo#711046, bgo#711046, bgo#711046, bgo#711046,
    bgo#711046, bgo#711046, bgo#711046, bgo#711046, bgo#711046,
    bgo#711046.
- Replace pkgconfig(mozjs-17.0) BuildRequires with
  pkgconfig(mozjs-24), following upstream's switch to MozJS 24.
* Wed Nov 20 2013 dimstar@opensuse.org
- Update to version 1.39.0:
  + Bugs fixed: bgo#691409, bgo#703440, bgo#707297, bgo#708749,
    bgo#708831, bgo#708915, bgo#708920, bgo#709907, bgo#710697,
    bgo#710875, bgo#710878, bgo#711046, bgo#712242.
* Wed Sep 25 2013 dimstar@opensuse.org
- Update to version 1.38.1:
  + Build: Also dist another input file.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 1.38.0:
  + Console: don't have a NULL program name.
  + Build fixes.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 1.37.6:
  + stack: Add BeginRequest / EndRequest.
  + context: Turn on type inference.
  + configure: Remove HAVE_JS_CLASS_TRACE gunk.
  + Bugs fixed: bgo#704343, bgo#704406, bgo#704902, bgo#703826.
* Wed Jul 10 2013 zaitor@opensuse.org
- Update to version 1.37.4:
  + Bugs fixed: bgo#701196, bgo#701525, bgo#703068, bgo#703564.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 1.37.1:
  + Bugs fixed: bgo#670200, bgo#685436, bgo#690982, bgo#690984,
    bgo#693294, bgo#696933, bgo#697309, bgo#697436, bgo#697592,
    bgo#697816, bgo#697838, bgo#698182, bgo#698935, bgo#699783,
    bgo#699784, bgo#699817, bgo#699818, bgo#699878, bgo#700335,
    bgo#700336, bgo#700337, bgo#700529, bgo#700644, bgo#700668,
    bgo#700862.
- Replace pkgconfig(mozjs185) BuildRequires with
  pkgconfig(mozjs-17.0), following upstreams change.
* Mon Apr 22 2013 dimstar@opensuse.org
- Update to version 1.36.1:
  + Bugs fixed: bgo#670200, bgo#697436.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 1.36.0:
  + No changes since version 1.35.9.
* Thu Mar 21 2013 dimstar@opensuse.org
- Update to version 1.35.9:
  + Bugs fixed: bgo#694300, bgo#694355, bgo#691447, bgo#694373,
    bgo#694221, bgo#694828, bgo#694827, bgo#694873, bgo#695186.
* Tue Feb 19 2013 dimstar@opensuse.org
- Update to version 1.35.8:
  + Convert many native modules to JS modules (bgo#692025).
  + Bugs fixed: bgo#691996, bgo#690982, bgo#692214, bgo#693627,
    bgo#693676.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 1.35.4:
  + system: Remove getuid/getgid/getpid
  + Bugs fixed: bgo#690688, bgo#691016, bgo#678410, bgo#678410,
    bgo#691028, bgo#691029, bgo#691030, bgo#680730, bgo#690982,
    bgo#691038, bgo#691039, bgo#691108, bgo#691109, bgo#691307,
    bgo#690982, bgo#685513, bgo#691719.
* Wed Jan  9 2013 dimstar@opensuse.org
- Update to version 1.35.3:
  + Add new GBytes API and conversions
  + Rework dynamic class system
  + boxed: introduce support for complex constructors
  + Fix memory leaks
- Changes from version 1.35.2:
  + Gio: Don't eat errors when trying to call the initial
    asyncCallback
  + byteArray: Remove JSCLASS_CONSTRUCT_PROTOTYPE
  + Gjs: work around GType bug with dynamic types
  + Support Sun CC
  + Fix memory leaks.
* Sat Oct 20 2012 dimstar@opensuse.org
- Obsolete typelib-1_0-GjsDBus-1_0: this helps with updating from
  gnome 3.4 to gnome 3.6.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 1.34.0:
  + stack: Fix gjs_dumpstack (bgo#683992).
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 1.33.14:
  + Bugs fixed: bgo#684064.
- Add pkgconfig(libffi) BuildRequires: since gjs uses ffi
  functions, confiure now checks for libffi presence.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 1.33.10:
  + Throw an exception when registering a GType that already exists
  + Object: don't access priv->info if it's NULL
  + Misc bug fixes.
- Drop gjs-avoid_crash.patch: fixed upstream.
* Mon Aug 27 2012 dimstar@opensuse.org
- Add gjs-avoid_crash.patch: Fix crashes in gnome-shell.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 1.33.9:
  + Several changes in the GC system.
  + Fix memory leaks.
  + Fix compiler warnings.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 1.33.4:
  + Build: link everything to gio
  + Fix memory leaks
  + Fix various bugs and issues caught by the Clang static
    analyzer.
* Fri Jun 29 2012 dimstar@opensuse.org
- Update to version 1.33.3:
  + Introduce special marshalling for GErrors
  + Gio: Split GDBus implementation into helpers
  + Gio: modernize DBus bindings
  + Trace signal closures from the gobject instead of the context
    keep-alive.
* Fri Jun 29 2012 dimstar@opensuse.org
- Update to version 1.33.2:
  + gi: Improve error message when we get a non-function for a
    callback
  + Fold libgjs-gdbus.so into libgjs.so
  + GDBus: fix NotImplementedError message
  + system: add getpid(), getuid(), getgid()
  + Handle arrays of filenames
  + Rename GjsDBus to GjsPrivate
  + Import a new "format" module
  + Add argument names to our function's toString
  + Support Function.prototype.length
  + Fix various memory leaks.
- Rename typelib-1_0-GjsDBus-1_0 subpackage to
  typelib-1_0-GjsPrivate-1_0, following upstream change.
- Drop gjs-getpid_uid_gid.patch: fixed upstream.
* Thu Jun 28 2012 dimstar@opensuse.org
- Add gjs-getpid_uid_gid.patch: system: add getpid(), getuid(),
  getgid().
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 1.32.0:
  + No changes.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 1.31.22:
  + Various bug fixes and code changes.
  + Build fixes.
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Drop gjs-fix-build.patch: fixed upstream.
* Mon Mar  5 2012 vuntz@opensuse.org
- Update to version 1.31.20:
  + Represent GTypes as a new boxed wrapper type
  + Add "system" module
  + Introduce meta classes
  + object:
  - Implement gobject inheritance
  - Add support for glib properties
  - Add support for signals
  - Add support for interfaces
  + Support callbacks that accept array arguments
  + Various gjs_parse_args() improvements
  + Several other code changes.
- Add gjs-fix-build.patch: fix code that cannot build.
* Thu Jan 19 2012 vuntz@opensuse.org
- Update to version 1.31.10:
  + Add native JSClass for interfaces
  + Add support for flat GValue arrays
  + Improvements related to singletons.
  + Fix ffi return value handling on 32 bit
  + Correctly convert from ffi return values to GIArgument on
    big-endian
  + Build fixes.
* Sat Dec 24 2011 vuntz@opensuse.org
- Split typelib file into typelib-1_0-GjsDBus-1_0 subpackage.
- Add typelib-1_0-GjsDBus-1_0 Requires to devel subpackage.
* Tue Dec 20 2011 vuntz@opensuse.org
- Update to version 1.31.6:
  + Require mozjs185.
  + Add a common way to grab a GType for an object
  + Some work to improve support for ParamSpec.
  + lang:
  - Add new "Class" framework adapted from MooTools
  - Improve prototype property descriptors
  - Introduce abstract classes
  - Fix for reentrant calls
  + console: Fix ARGV when using -c to specify program
  + Several overrides improvements.
  + Various other code changes.
- Remove %%build_with_xulrunner define: only building against
  mozjs185 is supported now.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Fri Oct 28 2011 dimstar@opensuse.org
- Update to version 1.31.0:
  + Fix memory leaks
  + Don't use deprecated g_thread_init() and gvalue calls.
  + Fix compiler warnings.
- Add pkgconfig(glib-2.0) BuildRequires.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 1.30.0:
  + No change, just a version bump.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 1.29.18:
  + Add optional signal emitted after a GC finishes
  + Add gjs_context_gc() wrapper
  + Run JS_updateMallocCounter() when creating GObjects
* Thu Sep  1 2011 vuntz@opensuse.org
- Update to version 1.29.17:
  + Add support for GPtrArrays.
  + Bind more cairo API.
  + Don't release too much when releasing arrays.
  + Misc bug fixes and improvements.
* Sun Jul 31 2011 vuntz@opensuse.org
- Update to version 1.29.16:
  + Make choice of javascript package non-automagic.
  + Install gi/ headers again.
* Wed Jul 27 2011 vuntz@opensuse.org
- Update to version 1.29.15:
  + Support in arrays of any type.
  + Rework array+length support, breaking API.
  + Various other array-related fixes.
  + Add GVariant support.
  + ADd GDBus port.
  + Add dbus conversion rule for 'q' to JS.
  + Remove SIGSEGV, SIGABRT handlers.
  + Merge gi.so into gjs.so.
  + Plug leaks.
  + console: Remove unwanted g_debug prints.
  + Various bug fixes.
  + Test-related changes.
* Fri Jun 17 2011 vuntz@opensuse.org
- Make it possible to build against js instead of xulrunner. This
  is controlled by a build_with_xulrunner define:
  + if it's set to a value other than 0, we keep the previous
    behavior.
  + if it's set to 0, we ignore all the xulrunner-related
    BuildRequires and Requires, and instead use a
    pkgconfig(mozjs185) BuildRequires.
- Stop pretending we build against xulrunner from old openSUSE.
* Wed Jun 15 2011 dimstar@opensuse.org
- Update to version 1.29.0:
  + Fix introspection annotations.
  + Add infrastructure for override modules.
  + Don't hide deprecated methods.
  + Parse input as UTF-8, not ISO-8859-1.
  + Fix gunichar args.
  + Support null terminated C arrays of any type.
  + Fix memory leak.
  + Adapt to changes in future xulrunner.
  + Support compilation with standalone mozjs185.
  + Various other fixes.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 0.7.14:
  + bgo#646246: Do connection processing in a high priority
    timeout.
- Changes from version 0.7.12:
  + bgo#643325: Make gjs_debugger_native_trap a JSFastNative
  + bgo#643817: mallinfo() is slow, look at /proc/self/statm
    instead.
  + Various cleanups.
* Tue Mar  1 2011 dimstar@opensuse.org
- Update to version 0.7.11:
  + Add gjs_context_maybe_gc() which is similar to JS_MaybeGC but
    tries to account for native allocations made directly from libc
    when determining if GC is useful. Also invoke after creating
    new native objects.
  + Adapt to additional xulrunner 2.0 changes
  + Add back debugger module, with single nativeTrap() function to
    trigger debugger breakpoint
  + Fix bug with looking up namespaced native modules
  + Memory leak fix
  + Build fixes
- Drop gjs-xulrunner20b11-fix.patch: fixed upstream.
- This update addresses bnc#676079.
* Mon Feb 21 2011 vuntz@opensuse.org
- Add gjs-xulrunner20b11-fix.patch to adapt to API changes in
  latest xulrunner.
* Thu Jan 27 2011 vuntz@opensuse.org
- Update to version 0.7.10:
  + xul2: use JS_NewCompartmentAndGlobalObject to avoid crash with
    latest xulrunner 2.
  + console: don't segfault on huge lines
* Mon Jan 17 2011 vuntz@opensuse.org
- Update to version 0.7.9:
  + Adapt to JS_GetStringChars removal in xulrunner 2.
  + Handle wide ranging enum values better.
  + Some tests fixes.
- Add Url tag.
* Wed Dec 22 2010 dimstar@opensuse.org
- Update to version 0.7.8:
  + Add a js-version property the GjsContext object and also allow
    specifying a specific version via a comment of the form
    '// application/javascript;version=1.8'. If no version is
    specified, all SpiderMonkey extensions are allowed.
  + Integrate with cairo-gobject library for support of boxed
    Cairo types
  + Add support for (out caller-allocates)
  + Add support for gunichar type
  + Support signals with G_TYPE_POINTER argument using
    introspection information
  + When invoking callback for void-returning async D-Bus method
    implementations, allow empty parameter list instead of []
  + Ignore empty elements in the module search path instead of
    treating them as the current directory
  + Handle removal of JS_GetStringBytes() in Spidermonkey
  + Handle removal of JS_GetFunctionName() in Spidermonkey
  + Use new g_object_info_find_method_using_interfaces() to allow
    future caching.
  + Improve efficiency of module search
  + Fix problems with JS_Add/RemoveRoot pairing
  + Memory management fixes
  + Improve error and debugging messages
  + Build fixes
  + Bugs fixed: bgo#624811, bgo#632551, bgo#632626, bgo#632925,
    bgo#633199, bgo#633477, bgo#635359, bgo#635368, bgo#635371,
    bgo#635707, bgo#636263, bgo#636619, bgo#636927, bgo#636928,
    bgo#637246
* Fri Dec  3 2010 vuntz@opensuse.org
- Add explicit Requires of mozilla-xulrunner%%{xulrunner_ver} to
  libgjs0: the Requires on libmozjs.so is not enough, as there
  might be more than one provider, and it could be the wrong
  version of xulrunner.
* Tue Nov 16 2010 dimstar@opensuse.org
- Update to version 0.7.7:
  + bgo#632159: Adapt to removal of SlowNative functions
  + Support more recent development versions of XulRunner.
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 0.7.6:
  + bgo#610859: Add makeProxyClass() function to the dbus module
    for easy creation of proxy classes.
  + Add an extra test case.
  + Build fixes.
* Thu Oct 28 2010 prusnak@opensuse.org
- Use pkgconfig BuildRequires when possible:
  + old BuildRequires: cairo-devel, dbus-1-glib-devel,
    gobject-introspection-devel.
  + new BuildRequires: cairo, dbus-glib-1 and
    gobject-introspection-1.0.
- Rename libgjs-0 to libgjs0: this is the correct SLPP name. Add
  appropriate Provides/Obsoletes.
- Do not add explicit Requires of dbus-1-devel and
  gobject-introspection-devel for libgjs-devel: they will be added
  automatically.
- Use %%_smp_mflags, make and %%make_install, following our new best
  packaging practices.
* Thu Oct 28 2010 vuntz@opensuse.org
- Update to version 0.7.5:
  + Replace JS_SealObject by JS_FreezeObject.
  + Port all functions to JSFUN_FAST_NATIVE.
  + JS_IsNativeFrame replaced by JS_IsScriptFrame.
  + Separate "basic" API from "embedder/module".
  + Build fixes.
- Build against mozilla-xulrunner20 in 11.4 and later, and stop
  supporting the 11.1 build (that was using mozilla-xulrunner190).
* Tue Oct  5 2010 vuntz@opensuse.org
- Update to version 0.7.4:
  + Require single include use of headers.
  + Support xulrunner 1.9.3.
  + Make gjs_profiler_reset public.
  + Remove "debugger" module.
  + Replace call context with a concept of "current context".
  + Replace "load context" with a "import global".
  + Various other fixes.
- Drop gjs_gi_probes.d, gjs.stp.in source files: they are now
  included in tarball.
* Thu Sep 16 2010 vuntz@opensuse.org
- Update to version 0.7.2:
  + Fix 64 bit issues.
  + Explicitly link gjs-console against glib.
  + Update to (and require) gobject-introspection 0.9.5.
  + Various other fixes.
- Remove gir-repository Recommends: all the interesting gir files
  are now directly shipped with the libraries.
* Fri Jul 23 2010 vuntz@opensuse.org
- Update to version 0.7.1:
  + Add support for GArray to gjs_value_from_g_argument
  + Add support for GArray to gjs_value_to_g_argument
  + Add support for dtrace/SystemTap
  + Add a promise module
  + Handle GValues of type G_TYPE_STRV
  + [gdb-check] Add a script for easier use
  + Throw a better warning for GValues containing container types
  + [importer] Allow native modules in gjs.so
  + [gjs] Add a byteArray module.
  + Adjust for g-i change to remove machine-independent type tags
  + Various other fixes.
- Drop gjs-bgo623775.patch: fixed upstream.
- Enable systemtap support: add systemtap-sdt-devel BuildRequires,
  pass --enable-systemtap to configure. Add gjs_gi_probes.d and
  gjs.stp.in source files, which are missing from the tarball
  (bgo#625090).
* Thu Jul 15 2010 dimstar@opensuse.org
- Add gjs-bgo623775.patch, from upstream git to fix build with
  gobject-introspection 0.9.2.
* Fri May 28 2010 dimstar@opensuse.org
- Update to version 0.7:
  + Add support for "foreign structs" - which are structures that
    are referenced from gobject-introspection, but need glue
    code to actually handle them.
  + Hook cairo bindings to integrate with gobject-introspected
    libraries using new foreign struct support
  + Start working toward thread-safety by adding
    JS_BeginRequest/JS_EndRequest calls throughout the codebase
  + add Tweener.setTimeScale and Tweener.getTimeScale
  + Wrap cairo_copy_path, cairo_copy_path_flat, and
    cairo_append_path
  + Handle destroy callbacks of type other than GDestroyNotify
  + Handle flag arguments not registered with GObject
  + Log errors that occur in callbacks
  + Code cleanup
  + Build fixes
  + Bugs fixed: bgo#610357, bgo#614055, bgo#614344, bgo#615078,
    bgo#615222, bgo#617343, bgo#617568, bgo#617702, bgo#617972,
    bgo#618190, bgo#618195, bgo#618200, bgo#618201
* Fri Mar 26 2010 vuntz@opensuse.org
- Build against mozilla-xulrunner192-devel on openSUSE > 11.2.
- Add dbus-1-devel Requires to devel package.
* Fri Mar 19 2010 dimstar@opensuse.org
- Update to version 0.6:
  + Optimize function invocation using libffi directly, speeding up
    function invocation benchmarks by as much as 30%%.
  + Add a native Cairo module
  + Don't include user_data arguments for callbacks, in Javascript
    you should use closures instead
  + Add a --command/-c argument to gjs-console
  + Add gjs_context_get_native_context() to allow access to the
    native context
  + Improve internal API support for collecting function arguments
    and defining types
  + Add examples using gio and libsoup
  + Add datadir/share/gjs-1.0 to searchpath in addition to
    XDG_DATA_DIRS
  + Add -rpath for libmozjs when linking gjs-console
  + Improve test cases and add internal assertions
  + Bugs fixed: bgo#561524, bgo#604074, bgo#604076, bgo#606258,
    bgo#609691, bgo#609830, bgo#610320, bgo#610370, bgo#610574,
    bgo#611529, bgo#611585, bgo#611590, bgo#611591, bgo#611811.
    bgo#613106
- BuildRequire cairo-devel.
* Tue Feb 16 2010 dimstar@opensuse.org
- Update to version 0.5:
  + Add a test for DBus.getcurrentMessageContext()
  + [dbus] include service name in error messages
  + gjs_define_object_class(): generate correct object hierarchy
  + Log the gjs-console command-line on startup
  + move gjs_error_reporter into a C++ file jsapi-private.cpp
  + don't use PTRDIFF macro from private spidermonkey header
  + Require C++
  + bgo#584558 - Need print() function
  + Enable JIT if we can, by default
  + Make things build with glib 2.16
  + Allow null/undefined to be passed in to callbacks
  + Support for callback functions
- BuildRequire gcc-c++.
* Wed Aug 26 2009 vuntz@novell.com
- Update to version 0.4:
  + Use g_boxed methods for GValue copying/freeing
  + Add symbolic link from gjs to gjs-console in $(bindir)
  + Use gssize in gjs_string_from_utf8/gjs_string_from_filename
  + Don't use undefined variable in dbus exception
  + Add gjs_parse_args
  + Add a gettext module
  + Better toString() for introspection objects
  +  Port modules/mainloop to gjs_parse_args
  + scripts: don't hardcode path to python
  + switch DEBUG_DBUS_MARSHAL log messages to be compiled out by
    default
  + bgo#560048 - Use JS_SetPropertyAttributes to seal imports
  + autoconf-2.64 compat: Don't use $(builddir) or
    $(abs_top_builddir)
  + Fix gjs_crash_after_timeout() problems
* Thu Aug  6 2009 vuntz@novell.com
- Build against mozilla-xulrunner191.
* Tue Jul  7 2009 vuntz@novell.com
- Update to version 0.3:
  + DBus support
  + Support simple fields for boxed types
  + Support "copy construction" of boxed types
  + Support simple structures not registered as boxed
  - Allow access to nested structures
  - Allow direct assignment to nested structure fields
  - Allow enum and flag structure fields
  - Allow creating boxed wrapper without copy
  + Support for non-default constructor (i.e. constructors like
    GdkPixbuf.Pixbuf.new_from_file(file))
  + Add a Lang.bind function which binds the meaning of 'this'
  + Add an interactive console gjs-console
  + Allow code in directory modules (i.e. the code should reside in
    __init__.js files)
  + Fix handling of enum/flags return values
  + Handle non-gobject-registered flags
  + Add Tweener.registerSpecialProperty to tweener module
  + Add profiler for javascript code
  + Add gjs_context_get_all and gjs_dumpstack - useful to invoke
    from a debugger such as gdb
  + Support GHashTable
  + Add support for UNIX shebang (i.e. #!/usr/bin/gjs-console)
  + Support new introspection short/ushort type tags
  + Support GI_TYPE_TAG_FILENAME
  + Improve support for machine-dependent integer types and arrays
    of integers
  + Fix several memory leaks
  + Bugs fixed: bgo#560506, bgo#560670, bgo#560808, bgo#561514,
    bgo#561516, bgo#561849, bgo#562892, bgo#564424, bgo#564664,
    bgo#566185, bgo#567675, bgo#569178, bgo#570775, bgo#570964,
    bgo#580948, bgo#584560, bgo#584850, bgo#584858, bgo#584858,
    bgo#585386, bgo#585460, bgo#586665, bgo#586760, bgo#561203,
    bgo#561573, bgo#561585, bgo#561664, bgo#561686, bgo#561812,
    bgo#562575, bgo#565029, bgo#567078, bgo#569374, bgo#572113,
    bgo#572121, bgo#572130, bgo#572258, bgo#580865, bgo#580947,
    bgo#580957, bgo#581277, bgo#581384, bgo#581385, bgo#581389,
    bgo#582686, bgo#582704, bgo#582707, bgo#584849, bgo#560808
- Add dbus-1-glib-devel BuildRequires.
* Fri May  1 2009 vuntz@novell.com
- Initial package.
